<template>
    <div class="app-container">
        <div class="filter-container">
            <el-button class="filter-item" style="margin-left: 10px;" type="primary"  @click="openFlowInformationForm('新增','')">添加</el-button>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="FlowDataList"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="制度名称" prop="name" align="center">
                </el-table-column>
                <el-table-column label="制定时间" prop="settime" align="center">
                </el-table-column>
                <el-table-column label="上传时间" prop="createtime" align="center">
                </el-table-column>
                <el-table-column label="操作" align="center" width="180" class-name="small-padding fixed-width">
                    <template slot-scope="scope">
                        <el-button type="text" @click="openFlowInformationForm('修改',scope.row)">修改</el-button>
                        <el-button type="text" @click="download('下载',scope.row)">下载</el-button>
                        <el-button type="text" @click="deleteById('删除',scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"/>
        </div>
        <flowInformation ref="flowInformation" @getinfo="getFlowInformationData"></flowInformation>
    </div>
</template>

<script>
import {uploadUrl} from '@/assets/upload/url'
import flowInformation from "./components/flowInformation";
import { computePageCount } from '@/utils'
import {  getEmergencyList , deleteEmergency} from '@/api/emergency'
export default {
    name: "publicSecurityDepartment",
    props:["enterpriseId"],
    data(){
        return{
            tableKey:0,
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            searchContent:'',
            FlowDataList:[],
            searchForm:{
                province:'',
                city:'',
                district:'',
                street:'',
                committee:'',
                type:'',
            }
        }
    },
    components:{
        flowInformation
    },
    created(){
        this.getFlowInformationData()
    },
    methods:{
        async getFlowInformationData(){
            const params = {}
            params['pageIndex'] = this.currentPage
            params['pageSize'] = this.pageSize
            this.listLoading = true
            let res = await getEmergencyList(params,this.enterpriseId,"FLOW")
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.FlowDataList = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        openFlowInformationForm(title,value){
            this.$refs.flowInformation.showFlowInformationForm(title,value,this.enterpriseId)
        },
        deleteById(title,row){
            this.$confirm('删除此条信息，是否继续','提示',{
                confirmButtonText:'确定',
                cancelButtonText:'取消',
                type:'warning',
            }).then(()=> {
                deleteEmergency(row.id).then( ()=>{
                    this.getFlowInformationData()
                    this.$notify({
                        title:'成功',
                        message:'删除成功',
                        type:'success',
                        duration:2000,
                    })
                })
            })
        },
        download(title,row){
            window.open(uploadUrl()+row.enterpriseResources[0].url, '_blank')
        },
        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getFlowInformationData()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getFlowInformationData()
        },
    }
}
</script>

<style scoped>
.emergencyResponsePlan_area{
    margin-left: 10px;
}
</style>
